MCD landing
AYANT-DROIT ( #matricule, nom ayant-droit, lien )

- Le champ matricule fait partie de la clé primaire de la table. C'est une clé étrangère qui a migré à partir de l'entité EMPLOYÉ pour renforcer l'identifiant.
- Le champ nom ayant-droit fait partie de la clé primaire de la table. C'était déjà un identifiant de l'entité AYANT-DROIT.
- Le champ lien était déjà un simple attribut de l'entité AYANT-DROIT.

COMPOSER ( #réf. pièce composée, #réf. pièce composante, quantité )

- Les champs réf. pièce composée et réf. pièce composante constituent la clé primaire de la table. Ce sont des clés étrangères qui ont migré directement à partir de l'entité PIÈCE.
- Le champ quantité était déjà un simple attribut de l'association COMPOSER.

DÉPARTEMENT ( num. département, nom département )

- Le champ num. département constitue la clé primaire de la table. C'était déjà un identifiant de l'entité DÉPARTEMENT.
- Le champ nom département était déjà un simple attribut de l'entité DÉPARTEMENT.

EMPLOYÉ ( matricule, nom employé, #num. département! )

- Le champ matricule constitue la clé primaire de la table. C'était déjà un identifiant de l'entité EMPLOYÉ.
- Le champ nom employé était déjà un simple attribut de l'entité EMPLOYÉ.
- Le champ à saisie obligatoire num. département est une clé étrangère. Il a migré par l'association de dépendance fonctionnelle EMPLOYER à partir de l'entité DÉPARTEMENT en perdant son caractère identifiant.

FOURNIR ( #num. projet, #réf. pièce, #num. société, qté fournie )

- Le champ num. projet fait partie de la clé primaire de la table. C'est une clé étrangère qui a migré directement à partir de l'entité PROJET.
- Le champ réf. pièce fait partie de la clé primaire de la table. C'est une clé étrangère qui a migré directement à partir de l'entité PIÈCE.
- Le champ num. société fait partie de la clé primaire de la table. C'est une clé étrangère qui a migré directement à partir de l'entité SOCIÉTÉ.
- Le champ qté fournie était déjà un simple attribut de l'association FOURNIR.

PIÈCE ( réf. pièce, libellé pièce )

- Le champ réf. pièce constitue la clé primaire de la table. C'était déjà un identifiant de l'entité PIÈCE.
- Le champ libellé pièce était déjà un simple attribut de l'entité PIÈCE.

PROJET ( num. projet, nom projet, #matricule responsable? )

- Le champ num. projet constitue la clé primaire de la table. C'était déjà un identifiant de l'entité PROJET.
- Le champ nom projet était déjà un simple attribut de l'entité PROJET.
- Le champ à saisie facultative matricule responsable est une clé étrangère. Il a migré par l'association de dépendance fonctionnelle DIRIGER à partir de l'entité EMPLOYÉ en perdant son caractère identifiant.

REQUÉRIR ( #num. projet, #réf. pièce, qté requise )

- Le champ num. projet fait partie de la clé primaire de la table. C'est une clé étrangère qui a migré directement à partir de l'entité PROJET.
- Le champ réf. pièce fait partie de la clé primaire de la table. C'est une clé étrangère qui a migré directement à partir de l'entité PIÈCE.
- Le champ qté requise était déjà un simple attribut de l'association REQUÉRIR.

SOCIÉTÉ ( num. société, raison sociale, #num. société mère? )

- Le champ num. société constitue la clé primaire de la table. C'était déjà un identifiant de l'entité SOCIÉTÉ.
- Le champ raison sociale était déjà un simple attribut de l'entité SOCIÉTÉ.
- Le champ à saisie facultative num. société mère est une clé étrangère. Il a migré par l'association de dépendance fonctionnelle CONTRÔLER à partir de l'entité SOCIÉTÉ en perdant son caractère identifiant.

TRAVAILLER ( #matricule, #num. projet )

- Le champ matricule fait partie de la clé primaire de la table. C'est une clé étrangère qui a migré directement à partir de l'entité EMPLOYÉ.
- Le champ num. projet fait partie de la clé primaire de la table. C'est une clé étrangère qui a migré directement à partir de l'entité PROJET.